Class: Ability

Inherits:
Object
  • Object
show all
Includes:
CanCan::Ability
Defined in:
lib/generators/adminpanel/initialize/templates/ability.rb

Instance Method Summary collapse

Constructor Details

#initialize(user) ⇒ Ability

Returns a new instance of Ability.



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/generators/adminpanel/initialize/templates/ability.rb', line 4

def initialize(user)

  if user.group.name == 'Admin'
    can :manage, :all
  else
    # cannot :manage, Adminpanel::User
    # can :manage, Adminpanel::Analytic
    # can :manage, Adminpanel::Section
    # can :manage, Adminpanel::Gallery
    # can :manage, Adminpanel::Category
  end

  # The first argument to `can` is the action you are giving the user
  # permission to do.
  # If you pass :manage it will apply to every action. Other common actions
  # here are :read, :create, :update and :destroy.
  #
  # The second argument is the resource the user can perform the action on.
  # If you pass :all it will apply to every resource. Otherwise pass a Ruby
  # class of the resource.
  #
  # The third argument is an optional hash of conditions to further filter the
  # objects.
  # For example, here the user can only update published articles.
  #
  #   can :update, Article, :published => true
end